;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "yaml-pro" "20250817.452"
  "Parser-aided YAML editing features."
  '((emacs "26.1")
    (yaml  "0.5.1"))
  :url "https://github.com/zkry/yaml-pro"
  :commit "9b9509188e5b88bb933e98ab36ab992519b9554b"
  :revdesc "9b9509188e5b"
  :keywords '("tools"))
